import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
 * @stability stable
 */
export interface CloudtrailConfig extends cdktf.TerraformMetaArguments {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudtrail.html#cloud_watch_logs_group_arn Cloudtrail#cloud_watch_logs_group_arn}.
     *
     * @stability stable
     */
    readonly cloudWatchLogsGroupArn?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudtrail.html#cloud_watch_logs_role_arn Cloudtrail#cloud_watch_logs_role_arn}.
     *
     * @stability stable
     */
    readonly cloudWatchLogsRoleArn?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudtrail.html#enable_log_file_validation Cloudtrail#enable_log_file_validation}.
     *
     * @stability stable
     */
    readonly enableLogFileValidation?: boolean;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudtrail.html#enable_logging Cloudtrail#enable_logging}.
     *
     * @stability stable
     */
    readonly enableLogging?: boolean;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudtrail.html#include_global_service_events Cloudtrail#include_global_service_events}.
     *
     * @stability stable
     */
    readonly includeGlobalServiceEvents?: boolean;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudtrail.html#is_multi_region_trail Cloudtrail#is_multi_region_trail}.
     *
     * @stability stable
     */
    readonly isMultiRegionTrail?: boolean;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudtrail.html#is_organization_trail Cloudtrail#is_organization_trail}.
     *
     * @stability stable
     */
    readonly isOrganizationTrail?: boolean;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudtrail.html#kms_key_id Cloudtrail#kms_key_id}.
     *
     * @stability stable
     */
    readonly kmsKeyId?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudtrail.html#name Cloudtrail#name}.
     *
     * @stability stable
     */
    readonly name: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudtrail.html#s3_bucket_name Cloudtrail#s3_bucket_name}.
     *
     * @stability stable
     */
    readonly s3BucketName: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudtrail.html#s3_key_prefix Cloudtrail#s3_key_prefix}.
     *
     * @stability stable
     */
    readonly s3KeyPrefix?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudtrail.html#sns_topic_name Cloudtrail#sns_topic_name}.
     *
     * @stability stable
     */
    readonly snsTopicName?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudtrail.html#tags Cloudtrail#tags}.
     *
     * @stability stable
     */
    readonly tags?: {
        [key: string]: string;
    };
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudtrail.html#tags_all Cloudtrail#tags_all}.
     *
     * @stability stable
     */
    readonly tagsAll?: {
        [key: string]: string;
    };
    /**
     * event_selector block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudtrail.html#event_selector Cloudtrail#event_selector}
     *
     * @stability stable
     */
    readonly eventSelector?: CloudtrailEventSelector[];
    /**
     * insight_selector block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudtrail.html#insight_selector Cloudtrail#insight_selector}
     *
     * @stability stable
     */
    readonly insightSelector?: CloudtrailInsightSelector[];
}
/**
 * @stability stable
 */
export interface CloudtrailEventSelectorDataResource {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudtrail.html#type Cloudtrail#type}.
     *
     * @stability stable
     */
    readonly type: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudtrail.html#values Cloudtrail#values}.
     *
     * @stability stable
     */
    readonly values: string[];
}
/**
 * @stability stable
 */
export interface CloudtrailEventSelector {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudtrail.html#include_management_events Cloudtrail#include_management_events}.
     *
     * @stability stable
     */
    readonly includeManagementEvents?: boolean;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudtrail.html#read_write_type Cloudtrail#read_write_type}.
     *
     * @stability stable
     */
    readonly readWriteType?: string;
    /**
     * data_resource block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudtrail.html#data_resource Cloudtrail#data_resource}
     *
     * @stability stable
     */
    readonly dataResource?: CloudtrailEventSelectorDataResource[];
}
/**
 * @stability stable
 */
export interface CloudtrailInsightSelector {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudtrail.html#insight_type Cloudtrail#insight_type}.
     *
     * @stability stable
     */
    readonly insightType: string;
}
/**
 * Represents a {@link https://www.terraform.io/docs/providers/aws/r/cloudtrail.html aws_cloudtrail}.
 *
 * @stability stable
 */
export declare class Cloudtrail extends cdktf.TerraformResource {
    /**
     * Create a new {@link https://www.terraform.io/docs/providers/aws/r/cloudtrail.html aws_cloudtrail} Resource.
     *
     * @param scope The scope in which to define this construct.
     * @param id The scoped construct ID.
     * @stability stable
     */
    constructor(scope: Construct, id: string, config: CloudtrailConfig);
    /**
     * @stability stable
     */
    get arn(): string;
    private _cloudWatchLogsGroupArn?;
    /**
     * @stability stable
     */
    get cloudWatchLogsGroupArn(): string;
    /**
     * @stability stable
     */
    set cloudWatchLogsGroupArn(value: string);
    /**
     * @stability stable
     */
    resetCloudWatchLogsGroupArn(): void;
    /**
     * @stability stable
     */
    get cloudWatchLogsGroupArnInput(): string | undefined;
    private _cloudWatchLogsRoleArn?;
    /**
     * @stability stable
     */
    get cloudWatchLogsRoleArn(): string;
    /**
     * @stability stable
     */
    set cloudWatchLogsRoleArn(value: string);
    /**
     * @stability stable
     */
    resetCloudWatchLogsRoleArn(): void;
    /**
     * @stability stable
     */
    get cloudWatchLogsRoleArnInput(): string | undefined;
    private _enableLogFileValidation?;
    /**
     * @stability stable
     */
    get enableLogFileValidation(): boolean;
    /**
     * @stability stable
     */
    set enableLogFileValidation(value: boolean);
    /**
     * @stability stable
     */
    resetEnableLogFileValidation(): void;
    /**
     * @stability stable
     */
    get enableLogFileValidationInput(): boolean | undefined;
    private _enableLogging?;
    /**
     * @stability stable
     */
    get enableLogging(): boolean;
    /**
     * @stability stable
     */
    set enableLogging(value: boolean);
    /**
     * @stability stable
     */
    resetEnableLogging(): void;
    /**
     * @stability stable
     */
    get enableLoggingInput(): boolean | undefined;
    /**
     * @stability stable
     */
    get homeRegion(): string;
    /**
     * @stability stable
     */
    get id(): string;
    private _includeGlobalServiceEvents?;
    /**
     * @stability stable
     */
    get includeGlobalServiceEvents(): boolean;
    /**
     * @stability stable
     */
    set includeGlobalServiceEvents(value: boolean);
    /**
     * @stability stable
     */
    resetIncludeGlobalServiceEvents(): void;
    /**
     * @stability stable
     */
    get includeGlobalServiceEventsInput(): boolean | undefined;
    private _isMultiRegionTrail?;
    /**
     * @stability stable
     */
    get isMultiRegionTrail(): boolean;
    /**
     * @stability stable
     */
    set isMultiRegionTrail(value: boolean);
    /**
     * @stability stable
     */
    resetIsMultiRegionTrail(): void;
    /**
     * @stability stable
     */
    get isMultiRegionTrailInput(): boolean | undefined;
    private _isOrganizationTrail?;
    /**
     * @stability stable
     */
    get isOrganizationTrail(): boolean;
    /**
     * @stability stable
     */
    set isOrganizationTrail(value: boolean);
    /**
     * @stability stable
     */
    resetIsOrganizationTrail(): void;
    /**
     * @stability stable
     */
    get isOrganizationTrailInput(): boolean | undefined;
    private _kmsKeyId?;
    /**
     * @stability stable
     */
    get kmsKeyId(): string;
    /**
     * @stability stable
     */
    set kmsKeyId(value: string);
    /**
     * @stability stable
     */
    resetKmsKeyId(): void;
    /**
     * @stability stable
     */
    get kmsKeyIdInput(): string | undefined;
    private _name;
    /**
     * @stability stable
     */
    get name(): string;
    /**
     * @stability stable
     */
    set name(value: string);
    /**
     * @stability stable
     */
    get nameInput(): string;
    private _s3BucketName;
    /**
     * @stability stable
     */
    get s3BucketName(): string;
    /**
     * @stability stable
     */
    set s3BucketName(value: string);
    /**
     * @stability stable
     */
    get s3BucketNameInput(): string;
    private _s3KeyPrefix?;
    /**
     * @stability stable
     */
    get s3KeyPrefix(): string;
    /**
     * @stability stable
     */
    set s3KeyPrefix(value: string);
    /**
     * @stability stable
     */
    resetS3KeyPrefix(): void;
    /**
     * @stability stable
     */
    get s3KeyPrefixInput(): string | undefined;
    private _snsTopicName?;
    /**
     * @stability stable
     */
    get snsTopicName(): string;
    /**
     * @stability stable
     */
    set snsTopicName(value: string);
    /**
     * @stability stable
     */
    resetSnsTopicName(): void;
    /**
     * @stability stable
     */
    get snsTopicNameInput(): string | undefined;
    private _tags?;
    /**
     * @stability stable
     */
    get tags(): {
        [key: string]: string;
    };
    /**
     * @stability stable
     */
    set tags(value: {
        [key: string]: string;
    });
    /**
     * @stability stable
     */
    resetTags(): void;
    /**
     * @stability stable
     */
    get tagsInput(): {
        [key: string]: string;
    } | undefined;
    private _tagsAll?;
    /**
     * @stability stable
     */
    get tagsAll(): {
        [key: string]: string;
    };
    /**
     * @stability stable
     */
    set tagsAll(value: {
        [key: string]: string;
    });
    /**
     * @stability stable
     */
    resetTagsAll(): void;
    /**
     * @stability stable
     */
    get tagsAllInput(): {
        [key: string]: string;
    } | undefined;
    private _eventSelector?;
    /**
     * @stability stable
     */
    get eventSelector(): CloudtrailEventSelector[];
    /**
     * @stability stable
     */
    set eventSelector(value: CloudtrailEventSelector[]);
    /**
     * @stability stable
     */
    resetEventSelector(): void;
    /**
     * @stability stable
     */
    get eventSelectorInput(): CloudtrailEventSelector[] | undefined;
    private _insightSelector?;
    /**
     * @stability stable
     */
    get insightSelector(): CloudtrailInsightSelector[];
    /**
     * @stability stable
     */
    set insightSelector(value: CloudtrailInsightSelector[]);
    /**
     * @stability stable
     */
    resetInsightSelector(): void;
    /**
     * @stability stable
     */
    get insightSelectorInput(): CloudtrailInsightSelector[] | undefined;
    /**
     * @stability stable
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
