import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
 * @stability stable
 */
export interface EcrpublicRepositoryConfig extends cdktf.TerraformMetaArguments {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ecrpublic_repository.html#force_destroy EcrpublicRepository#force_destroy}.
     *
     * @stability stable
     */
    readonly forceDestroy?: boolean;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ecrpublic_repository.html#repository_name EcrpublicRepository#repository_name}.
     *
     * @stability stable
     */
    readonly repositoryName: string;
    /**
     * catalog_data block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ecrpublic_repository.html#catalog_data EcrpublicRepository#catalog_data}
     *
     * @stability stable
     */
    readonly catalogData?: EcrpublicRepositoryCatalogData[];
    /**
     * timeouts block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ecrpublic_repository.html#timeouts EcrpublicRepository#timeouts}
     *
     * @stability stable
     */
    readonly timeouts?: EcrpublicRepositoryTimeouts;
}
/**
 * @stability stable
 */
export interface EcrpublicRepositoryCatalogData {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ecrpublic_repository.html#about_text EcrpublicRepository#about_text}.
     *
     * @stability stable
     */
    readonly aboutText?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ecrpublic_repository.html#architectures EcrpublicRepository#architectures}.
     *
     * @stability stable
     */
    readonly architectures?: string[];
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ecrpublic_repository.html#description EcrpublicRepository#description}.
     *
     * @stability stable
     */
    readonly description?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ecrpublic_repository.html#logo_image_blob EcrpublicRepository#logo_image_blob}.
     *
     * @stability stable
     */
    readonly logoImageBlob?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ecrpublic_repository.html#operating_systems EcrpublicRepository#operating_systems}.
     *
     * @stability stable
     */
    readonly operatingSystems?: string[];
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ecrpublic_repository.html#usage_text EcrpublicRepository#usage_text}.
     *
     * @stability stable
     */
    readonly usageText?: string;
}
/**
 * @stability stable
 */
export interface EcrpublicRepositoryTimeouts {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ecrpublic_repository.html#delete EcrpublicRepository#delete}.
     *
     * @stability stable
     */
    readonly delete?: string;
}
/**
 * Represents a {@link https://www.terraform.io/docs/providers/aws/r/ecrpublic_repository.html aws_ecrpublic_repository}.
 *
 * @stability stable
 */
export declare class EcrpublicRepository extends cdktf.TerraformResource {
    /**
     * Create a new {@link https://www.terraform.io/docs/providers/aws/r/ecrpublic_repository.html aws_ecrpublic_repository} Resource.
     *
     * @param scope The scope in which to define this construct.
     * @param id The scoped construct ID.
     * @stability stable
     */
    constructor(scope: Construct, id: string, config: EcrpublicRepositoryConfig);
    /**
     * @stability stable
     */
    get arn(): string;
    private _forceDestroy?;
    /**
     * @stability stable
     */
    get forceDestroy(): boolean;
    /**
     * @stability stable
     */
    set forceDestroy(value: boolean);
    /**
     * @stability stable
     */
    resetForceDestroy(): void;
    /**
     * @stability stable
     */
    get forceDestroyInput(): boolean | undefined;
    /**
     * @stability stable
     */
    get id(): string;
    /**
     * @stability stable
     */
    get registryId(): string;
    private _repositoryName;
    /**
     * @stability stable
     */
    get repositoryName(): string;
    /**
     * @stability stable
     */
    set repositoryName(value: string);
    /**
     * @stability stable
     */
    get repositoryNameInput(): string;
    /**
     * @stability stable
     */
    get repositoryUri(): string;
    private _catalogData?;
    /**
     * @stability stable
     */
    get catalogData(): EcrpublicRepositoryCatalogData[];
    /**
     * @stability stable
     */
    set catalogData(value: EcrpublicRepositoryCatalogData[]);
    /**
     * @stability stable
     */
    resetCatalogData(): void;
    /**
     * @stability stable
     */
    get catalogDataInput(): EcrpublicRepositoryCatalogData[] | undefined;
    private _timeouts?;
    /**
     * @stability stable
     */
    get timeouts(): EcrpublicRepositoryTimeouts;
    /**
     * @stability stable
     */
    set timeouts(value: EcrpublicRepositoryTimeouts);
    /**
     * @stability stable
     */
    resetTimeouts(): void;
    /**
     * @stability stable
     */
    get timeoutsInput(): EcrpublicRepositoryTimeouts | undefined;
    /**
     * @stability stable
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
