import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
 * @stability stable
 */
export interface EipConfig extends cdktf.TerraformMetaArguments {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/eip.html#address Eip#address}.
     *
     * @stability stable
     */
    readonly address?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/eip.html#associate_with_private_ip Eip#associate_with_private_ip}.
     *
     * @stability stable
     */
    readonly associateWithPrivateIp?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/eip.html#customer_owned_ipv4_pool Eip#customer_owned_ipv4_pool}.
     *
     * @stability stable
     */
    readonly customerOwnedIpv4Pool?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/eip.html#instance Eip#instance}.
     *
     * @stability stable
     */
    readonly instance?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/eip.html#network_border_group Eip#network_border_group}.
     *
     * @stability stable
     */
    readonly networkBorderGroup?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/eip.html#network_interface Eip#network_interface}.
     *
     * @stability stable
     */
    readonly networkInterface?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/eip.html#public_ipv4_pool Eip#public_ipv4_pool}.
     *
     * @stability stable
     */
    readonly publicIpv4Pool?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/eip.html#tags Eip#tags}.
     *
     * @stability stable
     */
    readonly tags?: {
        [key: string]: string;
    };
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/eip.html#tags_all Eip#tags_all}.
     *
     * @stability stable
     */
    readonly tagsAll?: {
        [key: string]: string;
    };
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/eip.html#vpc Eip#vpc}.
     *
     * @stability stable
     */
    readonly vpc?: boolean;
    /**
     * timeouts block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/eip.html#timeouts Eip#timeouts}
     *
     * @stability stable
     */
    readonly timeouts?: EipTimeouts;
}
/**
 * @stability stable
 */
export interface EipTimeouts {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/eip.html#delete Eip#delete}.
     *
     * @stability stable
     */
    readonly delete?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/eip.html#read Eip#read}.
     *
     * @stability stable
     */
    readonly read?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/eip.html#update Eip#update}.
     *
     * @stability stable
     */
    readonly update?: string;
}
/**
 * Represents a {@link https://www.terraform.io/docs/providers/aws/r/eip.html aws_eip}.
 *
 * @stability stable
 */
export declare class Eip extends cdktf.TerraformResource {
    /**
     * Create a new {@link https://www.terraform.io/docs/providers/aws/r/eip.html aws_eip} Resource.
     *
     * @param scope The scope in which to define this construct.
     * @param id The scoped construct ID.
     * @stability stable
     */
    constructor(scope: Construct, id: string, config?: EipConfig);
    private _address?;
    /**
     * @stability stable
     */
    get address(): string;
    /**
     * @stability stable
     */
    set address(value: string);
    /**
     * @stability stable
     */
    resetAddress(): void;
    /**
     * @stability stable
     */
    get addressInput(): string | undefined;
    /**
     * @stability stable
     */
    get allocationId(): string;
    private _associateWithPrivateIp?;
    /**
     * @stability stable
     */
    get associateWithPrivateIp(): string;
    /**
     * @stability stable
     */
    set associateWithPrivateIp(value: string);
    /**
     * @stability stable
     */
    resetAssociateWithPrivateIp(): void;
    /**
     * @stability stable
     */
    get associateWithPrivateIpInput(): string | undefined;
    /**
     * @stability stable
     */
    get associationId(): string;
    /**
     * @stability stable
     */
    get carrierIp(): string;
    /**
     * @stability stable
     */
    get customerOwnedIp(): string;
    private _customerOwnedIpv4Pool?;
    /**
     * @stability stable
     */
    get customerOwnedIpv4Pool(): string;
    /**
     * @stability stable
     */
    set customerOwnedIpv4Pool(value: string);
    /**
     * @stability stable
     */
    resetCustomerOwnedIpv4Pool(): void;
    /**
     * @stability stable
     */
    get customerOwnedIpv4PoolInput(): string | undefined;
    /**
     * @stability stable
     */
    get domain(): string;
    /**
     * @stability stable
     */
    get id(): string;
    private _instance?;
    /**
     * @stability stable
     */
    get instance(): string;
    /**
     * @stability stable
     */
    set instance(value: string);
    /**
     * @stability stable
     */
    resetInstance(): void;
    /**
     * @stability stable
     */
    get instanceInput(): string | undefined;
    private _networkBorderGroup?;
    /**
     * @stability stable
     */
    get networkBorderGroup(): string;
    /**
     * @stability stable
     */
    set networkBorderGroup(value: string);
    /**
     * @stability stable
     */
    resetNetworkBorderGroup(): void;
    /**
     * @stability stable
     */
    get networkBorderGroupInput(): string | undefined;
    private _networkInterface?;
    /**
     * @stability stable
     */
    get networkInterface(): string;
    /**
     * @stability stable
     */
    set networkInterface(value: string);
    /**
     * @stability stable
     */
    resetNetworkInterface(): void;
    /**
     * @stability stable
     */
    get networkInterfaceInput(): string | undefined;
    /**
     * @stability stable
     */
    get privateDns(): string;
    /**
     * @stability stable
     */
    get privateIp(): string;
    /**
     * @stability stable
     */
    get publicDns(): string;
    /**
     * @stability stable
     */
    get publicIp(): string;
    private _publicIpv4Pool?;
    /**
     * @stability stable
     */
    get publicIpv4Pool(): string;
    /**
     * @stability stable
     */
    set publicIpv4Pool(value: string);
    /**
     * @stability stable
     */
    resetPublicIpv4Pool(): void;
    /**
     * @stability stable
     */
    get publicIpv4PoolInput(): string | undefined;
    private _tags?;
    /**
     * @stability stable
     */
    get tags(): {
        [key: string]: string;
    };
    /**
     * @stability stable
     */
    set tags(value: {
        [key: string]: string;
    });
    /**
     * @stability stable
     */
    resetTags(): void;
    /**
     * @stability stable
     */
    get tagsInput(): {
        [key: string]: string;
    } | undefined;
    private _tagsAll?;
    /**
     * @stability stable
     */
    get tagsAll(): {
        [key: string]: string;
    };
    /**
     * @stability stable
     */
    set tagsAll(value: {
        [key: string]: string;
    });
    /**
     * @stability stable
     */
    resetTagsAll(): void;
    /**
     * @stability stable
     */
    get tagsAllInput(): {
        [key: string]: string;
    } | undefined;
    private _vpc?;
    /**
     * @stability stable
     */
    get vpc(): boolean;
    /**
     * @stability stable
     */
    set vpc(value: boolean);
    /**
     * @stability stable
     */
    resetVpc(): void;
    /**
     * @stability stable
     */
    get vpcInput(): boolean | undefined;
    private _timeouts?;
    /**
     * @stability stable
     */
    get timeouts(): EipTimeouts;
    /**
     * @stability stable
     */
    set timeouts(value: EipTimeouts);
    /**
     * @stability stable
     */
    resetTimeouts(): void;
    /**
     * @stability stable
     */
    get timeoutsInput(): EipTimeouts | undefined;
    /**
     * @stability stable
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
