import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
 * @stability stable
 */
export interface S3AccessPointConfig extends cdktf.TerraformMetaArguments {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_access_point.html#account_id S3AccessPoint#account_id}.
     *
     * @stability stable
     */
    readonly accountId?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_access_point.html#bucket S3AccessPoint#bucket}.
     *
     * @stability stable
     */
    readonly bucket: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_access_point.html#name S3AccessPoint#name}.
     *
     * @stability stable
     */
    readonly name: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_access_point.html#policy S3AccessPoint#policy}.
     *
     * @stability stable
     */
    readonly policy?: string;
    /**
     * public_access_block_configuration block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_access_point.html#public_access_block_configuration S3AccessPoint#public_access_block_configuration}
     *
     * @stability stable
     */
    readonly publicAccessBlockConfiguration?: S3AccessPointPublicAccessBlockConfiguration[];
    /**
     * vpc_configuration block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_access_point.html#vpc_configuration S3AccessPoint#vpc_configuration}
     *
     * @stability stable
     */
    readonly vpcConfiguration?: S3AccessPointVpcConfiguration[];
}
/**
 * @stability stable
 */
export interface S3AccessPointPublicAccessBlockConfiguration {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_access_point.html#block_public_acls S3AccessPoint#block_public_acls}.
     *
     * @stability stable
     */
    readonly blockPublicAcls?: boolean;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_access_point.html#block_public_policy S3AccessPoint#block_public_policy}.
     *
     * @stability stable
     */
    readonly blockPublicPolicy?: boolean;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_access_point.html#ignore_public_acls S3AccessPoint#ignore_public_acls}.
     *
     * @stability stable
     */
    readonly ignorePublicAcls?: boolean;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_access_point.html#restrict_public_buckets S3AccessPoint#restrict_public_buckets}.
     *
     * @stability stable
     */
    readonly restrictPublicBuckets?: boolean;
}
/**
 * @stability stable
 */
export interface S3AccessPointVpcConfiguration {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_access_point.html#vpc_id S3AccessPoint#vpc_id}.
     *
     * @stability stable
     */
    readonly vpcId: string;
}
/**
 * Represents a {@link https://www.terraform.io/docs/providers/aws/r/s3_access_point.html aws_s3_access_point}.
 *
 * @stability stable
 */
export declare class S3AccessPoint extends cdktf.TerraformResource {
    /**
     * Create a new {@link https://www.terraform.io/docs/providers/aws/r/s3_access_point.html aws_s3_access_point} Resource.
     *
     * @param scope The scope in which to define this construct.
     * @param id The scoped construct ID.
     * @stability stable
     */
    constructor(scope: Construct, id: string, config: S3AccessPointConfig);
    private _accountId?;
    /**
     * @stability stable
     */
    get accountId(): string;
    /**
     * @stability stable
     */
    set accountId(value: string);
    /**
     * @stability stable
     */
    resetAccountId(): void;
    /**
     * @stability stable
     */
    get accountIdInput(): string | undefined;
    /**
     * @stability stable
     */
    get arn(): string;
    private _bucket;
    /**
     * @stability stable
     */
    get bucket(): string;
    /**
     * @stability stable
     */
    set bucket(value: string);
    /**
     * @stability stable
     */
    get bucketInput(): string;
    /**
     * @stability stable
     */
    get domainName(): string;
    /**
     * @stability stable
     */
    get hasPublicAccessPolicy(): boolean;
    /**
     * @stability stable
     */
    get id(): string;
    private _name;
    /**
     * @stability stable
     */
    get name(): string;
    /**
     * @stability stable
     */
    set name(value: string);
    /**
     * @stability stable
     */
    get nameInput(): string;
    /**
     * @stability stable
     */
    get networkOrigin(): string;
    private _policy?;
    /**
     * @stability stable
     */
    get policy(): string;
    /**
     * @stability stable
     */
    set policy(value: string);
    /**
     * @stability stable
     */
    resetPolicy(): void;
    /**
     * @stability stable
     */
    get policyInput(): string | undefined;
    private _publicAccessBlockConfiguration?;
    /**
     * @stability stable
     */
    get publicAccessBlockConfiguration(): S3AccessPointPublicAccessBlockConfiguration[];
    /**
     * @stability stable
     */
    set publicAccessBlockConfiguration(value: S3AccessPointPublicAccessBlockConfiguration[]);
    /**
     * @stability stable
     */
    resetPublicAccessBlockConfiguration(): void;
    /**
     * @stability stable
     */
    get publicAccessBlockConfigurationInput(): S3AccessPointPublicAccessBlockConfiguration[] | undefined;
    private _vpcConfiguration?;
    /**
     * @stability stable
     */
    get vpcConfiguration(): S3AccessPointVpcConfiguration[];
    /**
     * @stability stable
     */
    set vpcConfiguration(value: S3AccessPointVpcConfiguration[]);
    /**
     * @stability stable
     */
    resetVpcConfiguration(): void;
    /**
     * @stability stable
     */
    get vpcConfigurationInput(): S3AccessPointVpcConfiguration[] | undefined;
    /**
     * @stability stable
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
