import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
 * @stability stable
 */
export interface SecurityGroupRuleConfig extends cdktf.TerraformMetaArguments {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/security_group_rule.html#cidr_blocks SecurityGroupRule#cidr_blocks}.
     *
     * @stability stable
     */
    readonly cidrBlocks?: string[];
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/security_group_rule.html#description SecurityGroupRule#description}.
     *
     * @stability stable
     */
    readonly description?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/security_group_rule.html#from_port SecurityGroupRule#from_port}.
     *
     * @stability stable
     */
    readonly fromPort: number;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/security_group_rule.html#ipv6_cidr_blocks SecurityGroupRule#ipv6_cidr_blocks}.
     *
     * @stability stable
     */
    readonly ipv6CidrBlocks?: string[];
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/security_group_rule.html#prefix_list_ids SecurityGroupRule#prefix_list_ids}.
     *
     * @stability stable
     */
    readonly prefixListIds?: string[];
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/security_group_rule.html#protocol SecurityGroupRule#protocol}.
     *
     * @stability stable
     */
    readonly protocol: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/security_group_rule.html#security_group_id SecurityGroupRule#security_group_id}.
     *
     * @stability stable
     */
    readonly securityGroupId: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/security_group_rule.html#self SecurityGroupRule#self}.
     *
     * @stability stable
     */
    readonly selfAttribute?: boolean;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/security_group_rule.html#source_security_group_id SecurityGroupRule#source_security_group_id}.
     *
     * @stability stable
     */
    readonly sourceSecurityGroupId?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/security_group_rule.html#to_port SecurityGroupRule#to_port}.
     *
     * @stability stable
     */
    readonly toPort: number;
    /**
     * Type of rule, ingress (inbound) or egress (outbound).
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/security_group_rule.html#type SecurityGroupRule#type}
     *
     * @stability stable
     */
    readonly type: string;
}
/**
 * Represents a {@link https://www.terraform.io/docs/providers/aws/r/security_group_rule.html aws_security_group_rule}.
 *
 * @stability stable
 */
export declare class SecurityGroupRule extends cdktf.TerraformResource {
    /**
     * Create a new {@link https://www.terraform.io/docs/providers/aws/r/security_group_rule.html aws_security_group_rule} Resource.
     *
     * @param scope The scope in which to define this construct.
     * @param id The scoped construct ID.
     * @stability stable
     */
    constructor(scope: Construct, id: string, config: SecurityGroupRuleConfig);
    private _cidrBlocks?;
    /**
     * @stability stable
     */
    get cidrBlocks(): string[];
    /**
     * @stability stable
     */
    set cidrBlocks(value: string[]);
    /**
     * @stability stable
     */
    resetCidrBlocks(): void;
    /**
     * @stability stable
     */
    get cidrBlocksInput(): string[] | undefined;
    private _description?;
    /**
     * @stability stable
     */
    get description(): string;
    /**
     * @stability stable
     */
    set description(value: string);
    /**
     * @stability stable
     */
    resetDescription(): void;
    /**
     * @stability stable
     */
    get descriptionInput(): string | undefined;
    private _fromPort;
    /**
     * @stability stable
     */
    get fromPort(): number;
    /**
     * @stability stable
     */
    set fromPort(value: number);
    /**
     * @stability stable
     */
    get fromPortInput(): number;
    /**
     * @stability stable
     */
    get id(): string;
    private _ipv6CidrBlocks?;
    /**
     * @stability stable
     */
    get ipv6CidrBlocks(): string[];
    /**
     * @stability stable
     */
    set ipv6CidrBlocks(value: string[]);
    /**
     * @stability stable
     */
    resetIpv6CidrBlocks(): void;
    /**
     * @stability stable
     */
    get ipv6CidrBlocksInput(): string[] | undefined;
    private _prefixListIds?;
    /**
     * @stability stable
     */
    get prefixListIds(): string[];
    /**
     * @stability stable
     */
    set prefixListIds(value: string[]);
    /**
     * @stability stable
     */
    resetPrefixListIds(): void;
    /**
     * @stability stable
     */
    get prefixListIdsInput(): string[] | undefined;
    private _protocol;
    /**
     * @stability stable
     */
    get protocol(): string;
    /**
     * @stability stable
     */
    set protocol(value: string);
    /**
     * @stability stable
     */
    get protocolInput(): string;
    private _securityGroupId;
    /**
     * @stability stable
     */
    get securityGroupId(): string;
    /**
     * @stability stable
     */
    set securityGroupId(value: string);
    /**
     * @stability stable
     */
    get securityGroupIdInput(): string;
    private _self?;
    /**
     * @stability stable
     */
    get selfAttribute(): boolean;
    /**
     * @stability stable
     */
    set selfAttribute(value: boolean);
    /**
     * @stability stable
     */
    resetSelfAttribute(): void;
    /**
     * @stability stable
     */
    get selfAttributeInput(): boolean | undefined;
    private _sourceSecurityGroupId?;
    /**
     * @stability stable
     */
    get sourceSecurityGroupId(): string;
    /**
     * @stability stable
     */
    set sourceSecurityGroupId(value: string);
    /**
     * @stability stable
     */
    resetSourceSecurityGroupId(): void;
    /**
     * @stability stable
     */
    get sourceSecurityGroupIdInput(): string | undefined;
    private _toPort;
    /**
     * @stability stable
     */
    get toPort(): number;
    /**
     * @stability stable
     */
    set toPort(value: number);
    /**
     * @stability stable
     */
    get toPortInput(): number;
    private _type;
    /**
     * @stability stable
     */
    get type(): string;
    /**
     * @stability stable
     */
    set type(value: string);
    /**
     * @stability stable
     */
    get typeInput(): string;
    /**
     * @stability stable
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
