import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
 * @stability stable
 */
export interface WorkspacesWorkspaceConfig extends cdktf.TerraformMetaArguments {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/workspaces_workspace.html#bundle_id WorkspacesWorkspace#bundle_id}.
     *
     * @stability stable
     */
    readonly bundleId: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/workspaces_workspace.html#directory_id WorkspacesWorkspace#directory_id}.
     *
     * @stability stable
     */
    readonly directoryId: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/workspaces_workspace.html#root_volume_encryption_enabled WorkspacesWorkspace#root_volume_encryption_enabled}.
     *
     * @stability stable
     */
    readonly rootVolumeEncryptionEnabled?: boolean;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/workspaces_workspace.html#tags WorkspacesWorkspace#tags}.
     *
     * @stability stable
     */
    readonly tags?: {
        [key: string]: string;
    };
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/workspaces_workspace.html#tags_all WorkspacesWorkspace#tags_all}.
     *
     * @stability stable
     */
    readonly tagsAll?: {
        [key: string]: string;
    };
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/workspaces_workspace.html#user_name WorkspacesWorkspace#user_name}.
     *
     * @stability stable
     */
    readonly userName: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/workspaces_workspace.html#user_volume_encryption_enabled WorkspacesWorkspace#user_volume_encryption_enabled}.
     *
     * @stability stable
     */
    readonly userVolumeEncryptionEnabled?: boolean;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/workspaces_workspace.html#volume_encryption_key WorkspacesWorkspace#volume_encryption_key}.
     *
     * @stability stable
     */
    readonly volumeEncryptionKey?: string;
    /**
     * timeouts block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/workspaces_workspace.html#timeouts WorkspacesWorkspace#timeouts}
     *
     * @stability stable
     */
    readonly timeouts?: WorkspacesWorkspaceTimeouts;
    /**
     * workspace_properties block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/workspaces_workspace.html#workspace_properties WorkspacesWorkspace#workspace_properties}
     *
     * @stability stable
     */
    readonly workspaceProperties?: WorkspacesWorkspaceWorkspaceProperties[];
}
/**
 * @stability stable
 */
export interface WorkspacesWorkspaceTimeouts {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/workspaces_workspace.html#create WorkspacesWorkspace#create}.
     *
     * @stability stable
     */
    readonly create?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/workspaces_workspace.html#delete WorkspacesWorkspace#delete}.
     *
     * @stability stable
     */
    readonly delete?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/workspaces_workspace.html#update WorkspacesWorkspace#update}.
     *
     * @stability stable
     */
    readonly update?: string;
}
/**
 * @stability stable
 */
export interface WorkspacesWorkspaceWorkspaceProperties {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/workspaces_workspace.html#compute_type_name WorkspacesWorkspace#compute_type_name}.
     *
     * @stability stable
     */
    readonly computeTypeName?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/workspaces_workspace.html#root_volume_size_gib WorkspacesWorkspace#root_volume_size_gib}.
     *
     * @stability stable
     */
    readonly rootVolumeSizeGib?: number;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/workspaces_workspace.html#running_mode WorkspacesWorkspace#running_mode}.
     *
     * @stability stable
     */
    readonly runningMode?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/workspaces_workspace.html#running_mode_auto_stop_timeout_in_minutes WorkspacesWorkspace#running_mode_auto_stop_timeout_in_minutes}.
     *
     * @stability stable
     */
    readonly runningModeAutoStopTimeoutInMinutes?: number;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/workspaces_workspace.html#user_volume_size_gib WorkspacesWorkspace#user_volume_size_gib}.
     *
     * @stability stable
     */
    readonly userVolumeSizeGib?: number;
}
/**
 * Represents a {@link https://www.terraform.io/docs/providers/aws/r/workspaces_workspace.html aws_workspaces_workspace}.
 *
 * @stability stable
 */
export declare class WorkspacesWorkspace extends cdktf.TerraformResource {
    /**
     * Create a new {@link https://www.terraform.io/docs/providers/aws/r/workspaces_workspace.html aws_workspaces_workspace} Resource.
     *
     * @param scope The scope in which to define this construct.
     * @param id The scoped construct ID.
     * @stability stable
     */
    constructor(scope: Construct, id: string, config: WorkspacesWorkspaceConfig);
    private _bundleId;
    /**
     * @stability stable
     */
    get bundleId(): string;
    /**
     * @stability stable
     */
    set bundleId(value: string);
    /**
     * @stability stable
     */
    get bundleIdInput(): string;
    /**
     * @stability stable
     */
    get computerName(): string;
    private _directoryId;
    /**
     * @stability stable
     */
    get directoryId(): string;
    /**
     * @stability stable
     */
    set directoryId(value: string);
    /**
     * @stability stable
     */
    get directoryIdInput(): string;
    /**
     * @stability stable
     */
    get id(): string;
    /**
     * @stability stable
     */
    get ipAddress(): string;
    private _rootVolumeEncryptionEnabled?;
    /**
     * @stability stable
     */
    get rootVolumeEncryptionEnabled(): boolean;
    /**
     * @stability stable
     */
    set rootVolumeEncryptionEnabled(value: boolean);
    /**
     * @stability stable
     */
    resetRootVolumeEncryptionEnabled(): void;
    /**
     * @stability stable
     */
    get rootVolumeEncryptionEnabledInput(): boolean | undefined;
    /**
     * @stability stable
     */
    get state(): string;
    private _tags?;
    /**
     * @stability stable
     */
    get tags(): {
        [key: string]: string;
    };
    /**
     * @stability stable
     */
    set tags(value: {
        [key: string]: string;
    });
    /**
     * @stability stable
     */
    resetTags(): void;
    /**
     * @stability stable
     */
    get tagsInput(): {
        [key: string]: string;
    } | undefined;
    private _tagsAll?;
    /**
     * @stability stable
     */
    get tagsAll(): {
        [key: string]: string;
    };
    /**
     * @stability stable
     */
    set tagsAll(value: {
        [key: string]: string;
    });
    /**
     * @stability stable
     */
    resetTagsAll(): void;
    /**
     * @stability stable
     */
    get tagsAllInput(): {
        [key: string]: string;
    } | undefined;
    private _userName;
    /**
     * @stability stable
     */
    get userName(): string;
    /**
     * @stability stable
     */
    set userName(value: string);
    /**
     * @stability stable
     */
    get userNameInput(): string;
    private _userVolumeEncryptionEnabled?;
    /**
     * @stability stable
     */
    get userVolumeEncryptionEnabled(): boolean;
    /**
     * @stability stable
     */
    set userVolumeEncryptionEnabled(value: boolean);
    /**
     * @stability stable
     */
    resetUserVolumeEncryptionEnabled(): void;
    /**
     * @stability stable
     */
    get userVolumeEncryptionEnabledInput(): boolean | undefined;
    private _volumeEncryptionKey?;
    /**
     * @stability stable
     */
    get volumeEncryptionKey(): string;
    /**
     * @stability stable
     */
    set volumeEncryptionKey(value: string);
    /**
     * @stability stable
     */
    resetVolumeEncryptionKey(): void;
    /**
     * @stability stable
     */
    get volumeEncryptionKeyInput(): string | undefined;
    private _timeouts?;
    /**
     * @stability stable
     */
    get timeouts(): WorkspacesWorkspaceTimeouts;
    /**
     * @stability stable
     */
    set timeouts(value: WorkspacesWorkspaceTimeouts);
    /**
     * @stability stable
     */
    resetTimeouts(): void;
    /**
     * @stability stable
     */
    get timeoutsInput(): WorkspacesWorkspaceTimeouts | undefined;
    private _workspaceProperties?;
    /**
     * @stability stable
     */
    get workspaceProperties(): WorkspacesWorkspaceWorkspaceProperties[];
    /**
     * @stability stable
     */
    set workspaceProperties(value: WorkspacesWorkspaceWorkspaceProperties[]);
    /**
     * @stability stable
     */
    resetWorkspaceProperties(): void;
    /**
     * @stability stable
     */
    get workspacePropertiesInput(): WorkspacesWorkspaceWorkspaceProperties[] | undefined;
    /**
     * @stability stable
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
